from setuptools import setup

with open('README.md', 'r') as fh:
    long_description = fh.read()

setup(
    name='zipcreator',
    url='https://github.com/mpalazzolo/zipcreator',
    version='1.0.1',
    packages=['zipcreator'],
    license='LICENSE.txt',
    author='Matt Palazzolo',
    author_email='mattpalazzolo@gmail.com',
    description='A quick tool for creating a zipfile from a list of files and/or directories.',
    long_description=long_description,
    long_description_content_type='text/markdown',
)



import os
import zipfile


def create(items, destination, compression=zipfile.ZIP_DEFLATED):
    """
    Create the zipfile located at the given destination with the files specified.

    :param items: List of files ad directories as strings. Directories must end in /
    :param destination: path and filename of desired zip destination
    :param compression: Compression format for zip handler
    """
    zip_handler = zipfile.ZipFile(destination, 'w', compression)
    if len(items) > 0:
        for item in items:
            if item[-1] == '/':
                # Directory
                for root, dirs, files in os.walk(item):
                    zip_handler.write(root)
                    for file in files:
                        zip_handler.write(os.path.join(root, file))
            else:
                # File
                zip_handler.write(item)
    zip_handler.close()
